from datetime import timedelta

from data_gateway_sdk.protocols.smpm.smpm_ul_device_jupiter_16b_counter import SmpmUlDeviceJupiter16BCounterData
from data_gateway_sdk.utils.buf_ref import BufRef


def test_smpm_ul_device_jupiter_16b_counter() -> None:
    case_serialized = bytes.fromhex("810cc0ffff7fba90fdfffffffeffff7f")
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=33554431.0), temperature=23, battery_volts=3.3, event_reset=False, event_low_battery_level=False, event_temperature_limits=True, event_battery_warn=True, event_system_error=False, value_channel_1=1073741823, value_channel_2=1073741823) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=33554431.0), temperature=23, battery_volts=3.3, event_reset=False, event_low_battery_level=False, event_temperature_limits=True, event_battery_warn=True, event_system_error=False, value_channel_1=1073741823, value_channel_2=1073741823))  # noqa: E501
    case_serialized = bytes.fromhex("810c000000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c000000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c000000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c000000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c000000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c000000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c000000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c000000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c0000000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c0000000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c0000000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c0000000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c0000000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c0000000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c0000000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c0000000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c380000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c380000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c380000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c380000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c380000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c380000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c380000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c380000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c3800000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c3800000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c3800000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c3800000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c3800000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c3800000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c3800000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c3800000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc070000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc070000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc070000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc070000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc070000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc070000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc070000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc070000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc0700000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc0700000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc0700000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc0700000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc0700000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc0700000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc0700000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc0700000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f0000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f0000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f0000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f0000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f0000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f0000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f0000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f0000007fe00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f00000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f00000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f00000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f00000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f00000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f00000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f00000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f00000000e00300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=0.0, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=0.0, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c00000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c00000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c00000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c00000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c00000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c00000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c00000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c00000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c0000000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c0000000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c0000000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c0000000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c0000000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c0000000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c0000000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c0000000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c38000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c38000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c38000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c38000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c38000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c38000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c38000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c38000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c3800000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c3800000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c3800000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c3800000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c3800000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c3800000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("810c3800000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("810c3800000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=0.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=0.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc07000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc07000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc07000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc07000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc07000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc07000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc07000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc07000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc0700000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc0700000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc0700000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc0700000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc0700000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc0700000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc0700000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc0700000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=0.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=0.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f000000ffff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=92, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=92, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f00000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f00000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f00000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f00000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=0.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f00000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f00000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=0, value_channel_2=4294967296))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f00000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=0))  # noqa: E501
    case_serialized = bytes.fromhex("81cc3f00000080ff0300000000000000")  # overflow
    assert SmpmUlDeviceJupiter16BCounterData(days_ago=timedelta(seconds=2678400.0), sync_time_days_ago=timedelta(seconds=604800.0), timestamp_s=timedelta(seconds=0.0), temperature=-35, battery_volts=6.3, event_reset=True, event_low_battery_level=True, event_temperature_limits=True, event_battery_warn=True, event_system_error=True, value_channel_1=0, value_channel_2=0) == SmpmUlDeviceJupiter16BCounterData.parse(BufRef(case_serialized))  # noqa: E501
    assert case_serialized == SmpmUlDeviceJupiter16BCounterData.serialize(SmpmUlDeviceJupiter16BCounterData(battery_volts=6.3, days_ago=timedelta(seconds=2678400.0), event_battery_warn=True, event_low_battery_level=True, event_reset=True, event_system_error=True, event_temperature_limits=True, sync_time_days_ago=timedelta(seconds=604800.0), temperature=-35, timestamp_s=timedelta(seconds=134217728.0), value_channel_1=4294967296, value_channel_2=4294967296))  # noqa: E501
